import { AxiosInstance } from "axios";
import { AlgoBlock, ReadRpcInterface } from "..";
import { IBlockTip, IFullBlock } from "../base-objects/BlockBase";
import { AlgoIndexerBlock } from "../base-objects/blocks/AlgoIndexerBlock";
import { AlgoNodeStatus } from "../base-objects/StatusBase";
import { AlgoTransaction } from "../base-objects/TransactionBase";
import { AlgoIndexerTransaction } from "../base-objects/transactions/AlgoIndexerTransaction";
import { AlgoMccCreate, ChainType, IAlgoIndexerAsset, IAlgoListTransactionRes, IAlgoLitsTransaction } from "../types";
import { IAlgoAssets, IAlgoCert } from "../types/algoTypes";
export declare class ALGOImplementation implements ReadRpcInterface {
    algodClient: AxiosInstance;
    indexerClient: AxiosInstance | undefined;
    chainType: ChainType;
    inRegTest: boolean;
    createConfig: AlgoMccCreate;
    constructor(createConfig: AlgoMccCreate);
    getFullBlock(blockNumberOrHash: string | number): Promise<IFullBlock>;
    getBlockTips?(height_gte: number): Promise<IBlockTip[]>;
    getTopLiteBlocks(branch_len: number, read_main?: boolean): Promise<IBlockTip[]>;
    /**
     * Return node status object for Algo node
     */
    getNodeStatus(): Promise<AlgoNodeStatus>;
    getBottomBlockHeight(): Promise<number>;
    getBlock(round?: number): Promise<AlgoBlock>;
    getBlockHeader(blockNumberOrHash?: number): Promise<AlgoBlock>;
    getBlockHeight(round?: number): Promise<number>;
    getBlockProof(round: number): Promise<IAlgoCert>;
    /**
     * get Transaction cannot be called on algorand's algod client, use getIndexerTransaction instead or get transactions from block
     * @param txid
     */
    getTransaction(txid: string): Promise<AlgoTransaction>;
    listTransactions(options?: IAlgoLitsTransaction): Promise<IAlgoListTransactionRes | undefined>;
    getAssetInfo(assetId: number): Promise<IAlgoAssets>;
    private getStatus;
    private getBlockHeaderCert;
    private getBlockHeaderBase;
    /**
     * Get trasnaction from node by its id
     * @param txid base32 encoded txid || standardized txid (prefixed or unprefixed)
     * @returns
     */
    getIndexerTransaction(txid: string): Promise<AlgoIndexerTransaction | undefined>;
    getIndexerBlock(round?: number): Promise<AlgoIndexerBlock | undefined>;
    getIndexerAssetInfo(assetIndex: number): Promise<IAlgoIndexerAsset | undefined>;
}
//# sourceMappingURL=AlgoRpcImplementation.d.ts.map