"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getTestFile = exports.AddressAmountEqual = exports.singleAddressAmountEqual = exports.addressToBtyeAddress = exports.sendMinimalUTXOTransaction = exports.round_for_ltc = exports.expectThrow = void 0;
const chai_1 = require("chai");
const src_1 = require("../src");
const algoUtils_1 = require("../src/utils/algoUtils");
// eslint-disable-next-line @typescript-eslint/no-explicit-any
const expectThrow = async (method, errorMessage) => {
    let error = null;
    try {
        await method;
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
    }
    catch (err) {
        error = err;
    }
    if (typeof errorMessage === "object") {
        // eslint-disable-next-line guard-for-in
        for (const prop in errorMessage) {
            (0, chai_1.expect)(error).to.haveOwnProperty(prop);
            (0, chai_1.expect)(error[prop]).to.eq(errorMessage[prop]);
        }
    }
    else {
        (0, chai_1.expect)(error).to.equal(errorMessage);
    }
};
exports.expectThrow = expectThrow;
function round_for_ltc(input) {
    return parseFloat(input.toFixed(8));
}
exports.round_for_ltc = round_for_ltc;
// eslint-disable-next-line @typescript-eslint/no-explicit-any
async function sendMinimalUTXOTransaction(RPC, fromWalletLabel, from, to) {
    const unspent = await RPC.listUnspentTransactions(fromWalletLabel);
    const vin = [];
    const vinAddresses = [];
    let unspentAmount = 0;
    for (const utx of unspent) {
        console.log("ALL utxo", utx);
        if (utx.address == from) {
            console.log(utx);
            vin.push({
                txid: utx.txid,
                vout: utx.vout,
            });
            vinAddresses.push(utx.address);
            unspentAmount += utx.amount;
        }
    }
    const gas = 1e-5;
    const test_amount = 1e-5;
    if (unspentAmount < gas + test_amount) {
        console.error("Not enough founds on sender wallet");
        throw Error("Insufficient founds on sender wallet");
    }
    const vout = [
        { address: to, amount: test_amount },
        { address: from, amount: round_for_ltc(unspentAmount - test_amount - gas) },
    ];
    const a = await RPC.createRawTransaction(fromWalletLabel, vin, vout);
    const signKeys = [];
    for (const add of vinAddresses) {
        signKeys.push(await RPC.getPrivateKey(fromWalletLabel, add));
    }
    const signedTx = await RPC.signRawTransaction(fromWalletLabel, a, signKeys);
    const txId = await RPC.sendRawTransactionInBlock(fromWalletLabel, signedTx.hex);
    return txId;
}
exports.sendMinimalUTXOTransaction = sendMinimalUTXOTransaction;
function addressToBtyeAddress(address) {
    const algoKeyPair = (0, algoUtils_1.addressToHex)(address);
    return (0, algoUtils_1.hexToBytes)((0, src_1.unPrefix0x)(algoKeyPair.publicKey) + (0, src_1.unPrefix0x)(algoKeyPair.checksum));
}
exports.addressToBtyeAddress = addressToBtyeAddress;
function singleAddressAmountEqual(a, b) {
    return a.address == b.address && a.amount.toString() == b.amount.toString() && a.elementaryUnits == b.elementaryUnits && a.utxo == b.utxo;
}
exports.singleAddressAmountEqual = singleAddressAmountEqual;
function AddressAmountEqual(a, b) {
    if (a.length != b.length) {
        return false;
    }
    const sortParam = (x, y) => {
        if (!x.address || !y.address)
            return 1;
        if (x.address == y.address)
            return 0;
        if (x.address > y.address)
            return 1;
        else
            return -1;
    };
    a.sort(sortParam);
    b.sort(sortParam);
    for (let i = 0; i < a.length; i++) {
        if (singleAddressAmountEqual(a[i], b[i]) == false) {
            return false;
        }
    }
    return true;
}
exports.AddressAmountEqual = AddressAmountEqual;
/**
 * Returns truncated file path.
 * @param file module filename
 * @returns file path from `test/` on, separated by `'/'`
 */
function getTestFile(myFile) {
    return myFile.slice(myFile.replace(/\\/g, "/").indexOf("test/"));
}
exports.getTestFile = getTestFile;
//# sourceMappingURL=testUtils.js.map